#!/opt/sensu/embedded/bin/ruby
#  encoding: UTF-8
#
#  check-lan
#
# DESCRIPTION:
#   This plugin uses checks (standalone) if a given ip is reachable and if it is not restarts the given interface.
#	If this is not successfull this plugin reboots the client machine.
#
# PLATFORMS:
#   Linux
#
# DEPENDENCIES:
#   gem: sensu-plugin
#
# USAGE:
#
# NOTES:
#
# LICENSE:
#   Copyright 2017 Max
#   Released under the same terms as Sensu (the MIT license); see LICENSE
#   for details.

require 'sensu-plugin/check/cli'

class CheckLan < Sensu::Plugin::Check::CLI
	#change the IP whatever IP you want to ping.
	IP_TO_PING = "172.22.1.100"
	PING_COUNT = 1
	#change interface to the interface you want to check
	INTERFACE="eth0"

	PING = "/bin/ping"
	IFUP="/sbin/ifup"
	IFDOWN="/sbin/ifdown --force"

	#Method to ping the IP_TO_PING	
	def ping
		`#{PING} -c #{PING_COUNT} #{IP_TO_PING} > /dev/null 2> /dev/null`
	end
	
	def run
	
		puts "ping #{IP_TO_PING} for checking conectivity..."
		ping()
		if $?.exitstatus >= 1
			puts "#{INTERFACE} seems to be down, trying to bring it up..."
			puts "executing ifdown #{INTERFACE}"
			`sudo #{IFDOWN} #{INTERFACE} `
			puts "waiting 10 seconds to bring #{INTERFACE} up..."
			`sleep 10`
			puts "executing ifup #{INTERFACE}"
			`sudo #{IFUP} #{INTERFACE}`
			puts "waiting 10 seconds to ping again..."
			`sleep 10`
			puts "ping server again..."
			ping()
			if $?.exitstatus >= 1
				puts "#{INTERFACE} is still down, REBOOT to recover..."
				`sudo reboot`
				critical "REBOOT to recover"
			else
				#puts "Resetting #{INTERFACE} was successfull"
				ok "Resetting #{INTERFACE} was successfull"
			end
		else
			#puts "#{INTERFACE} is up"
			ok "#{INTERFACE} is up"
		end
	end
end
	

	